ReportLab Preppy Test Suite 006

# Preppy Test 006 - Writing HTML files without writing .py files

This test should create a readable HTML file (sample006.html), without any associated Python file (sample006.py).

## Expected Output

You are reading this HTML file, so this test worked.

Below is a listing of the files in the same directory as this HTML file. 'sample006.py' should not there.

00readme.txt | check_algorithms.py
check_algorithms.pyc | check_basics.py
check_basics.pyc | check_load.py
check_load.pyc | check_lowlevel.py
check_lowlevel.pyc | dummy_module.pyc
inner.prep | inner.pyc
inner1.prep | inner1.pyc
loadsample003.html | loadsample003.prep
loadsample003.prep.orig | loadsample003.pyc
loadsample004.html | loadsample004.prep
loadsample004.pyc | loadsample05.html
loadsample05.prep | loadsample05.pyc
oneMegTestFile.txt | outer.prep
sample001.html | sample001.prep
sample001.pyc | sample001n.prep
sample001n.pyc | sample002.html
sample002.prep | sample002.pyc
sample003.html | sample003.prep
sample003.pyc | sample004.html
sample004.prep | sample004.pyc
sample005.html | sample005.prep
sample005.pyc | sample006.html
sample006.prep | sample006.pyc
sample007.html | sample008.html
sample008.prep | sample008.pyc
sample009.html | sample009.prep
sample009.pyc | sample010.html
sample010.prep | sample010.pyc
sample011.html | sample011.prep
sample011.pyc | sample012.html
sample012.prep | sample012.pyc
sample013.prep | sample013_inner.prep
sixtyfiveKTestFile.txt | testall.py
testpreppy.prep | test_import_hook.py
test_import_hook.pyc | __init__.py
__init__.pyc |